@@ -561,6 +561,10 @@ class Database:
             df = df.set_index(keys='date')
             df = df.sort_index()
 
+            df['ss_ratio'] = df['ss_ratio'].astype(float)
+            df['ss_shares'] = df['ss_shares'].astype('int64')
+            df['ss_dollars'] = df['ss_dollars'].astype('int64')
+
             return df
 
     def get_hk_shortsell_by_date(self, start_date, end_date):
